@@ -5,9 +5,8 @@ use warnings;
 use EV;
 use Net::Curl::Easy qw(CURLE_COULDNT_CONNECT);
 use Net::Curl::Multi qw(CURLMSG_DONE CURL_SOCKET_TIMEOUT /^CURL_POLL_/ /^CURL_CSELECT_/ CURLMOPT_SOCKETFUNCTION CURLMOPT_TIMERFUNCTION);
-use Scalar::Util qw(weaken);
 
-our $VERSION = '0.01.6';
+our $VERSION = '0.01';
 
 BEGIN {
 	Net::Curl::Multi->can('CURLMOPT_TIMERFUNCTION') or
@@ -15,9 +14,12 @@ BEGIN {
 }
 
 
+
 sub curl_ev {
 	my ($multi) = @_;
 
+	$multi ||= Net::Curl::Multi->new();
+
 	my %finish = (); # easy => finish
 	my %timer  = (); # easy => sub
 
@@ -43,8 +45,6 @@ sub curl_ev {
 
 	my $cb_timeout = sub { $socket_action->(CURL_SOCKET_TIMEOUT) };
 
-	my $add_handle_timer;
-
 	# add one handle and kickstart download
 	my $add_handle = sub {
 		my ($easy, $finish, $timeout) = @_;
@@ -63,7 +63,7 @@ sub curl_ev {
 		# and it could confuse our application -- it would appear to
 		# have finished before it started.
 
-		$add_handle_timer = EV::timer 0, 0, $cb_timeout;
+		EV::timer 0, 0, $cb_timeout;
 
 		$multi->add_handle($easy);
 
@@ -130,8 +130,7 @@ sub curl_ev {
 			$timer = EV::timer 10, 10, $cb_timeout;
 		} else {
 			# This will trigger timeouts if there are any.
-			my $t = $timeout_ms / 1000;
-			$timer = EV::timer $t, $t, $cb_timeout;
+			$timer = EV::timer $timeout_ms / 1000, 0, $cb_timeout;
 		}
 
 		return 1;
@@ -140,8 +139,6 @@ sub curl_ev {
 	$multi->setopt(CURLMOPT_SOCKETFUNCTION, $cb_socket);
 	$multi->setopt(CURLMOPT_TIMERFUNCTION,  $cb_timer);
 
-	weaken $multi;
-
 	return $add_handle;
 }
 
@@ -152,7 +149,7 @@ __END__
 
 =head1 NAME
 
-Net::Curl::Multi::EV - Using Net::Curl::Multi with EV.
+Using Net::Curl::Multi with EV.
 
 =head1 SYNOPSIS
 
@@ -195,7 +192,7 @@ Nick Kostyria
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2013 by Nick Kostyria
+Copyright (C) 2013 by Nick Kostirya
 
 This library is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself, either Perl version 5.14.2 or,
@@ -205,6 +202,5 @@ at your option, any later version of Perl 5 you may have available.
 
 L<EV>
 L<Net::Curl>
-L<http://search.cpan.org/~syp/Net-Curl/lib/Net/Curl/examples.pod#Multi::Event>
 
 =cut
